summaryrefslogtreecommitdiffstats
path: root/ppapi/c
diff options
context:
space:
mode:
authorteravest@chromium.org <teravest@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-05-28 22:43:17 +0000
committerteravest@chromium.org <teravest@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-05-28 22:43:17 +0000
commit2efbb6470883c5c9d80ac49c86aa9b5c79ad451a (patch)
tree945b2f1150bba3aea4eb7e46e0e03cd76d9ba3fc /ppapi/c
parentf5a79d9c242a95280fda1f61adda146cd3b700c9 (diff)
downloadchromium_src-2efbb6470883c5c9d80ac49c86aa9b5c79ad451a.zip
chromium_src-2efbb6470883c5c9d80ac49c86aa9b5c79ad451a.tar.gz
chromium_src-2efbb6470883c5c9d80ac49c86aa9b5c79ad451a.tar.bz2
Pepper: Remove DescWrapper use in nexe loading.
This removes more uses of DescWrapper in the trusted plugin. This is necessary for moving nexe loading away from SRPC to Chrome IPC because we have no way to transmit NaClDescs or DescWrappers over Chrome IPC. BUG=333950 Review URL: https://codereview.chromium.org/301793005 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@273380 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ppapi/c')
-rw-r--r--ppapi/c/private/ppb_nacl_private.h12
1 files changed, 5 insertions, 7 deletions
diff --git a/ppapi/c/private/ppb_nacl_private.h b/ppapi/c/private/ppb_nacl_private.h
index eb898d3..608b73d 100644
--- a/ppapi/c/private/ppb_nacl_private.h
+++ b/ppapi/c/private/ppb_nacl_private.h
@@ -3,7 +3,7 @@
* found in the LICENSE file.
*/
-/* From private/ppb_nacl_private.idl modified Fri May 23 08:51:49 2014. */
+/* From private/ppb_nacl_private.idl modified Wed May 28 09:02:13 2014. */
#ifndef PPAPI_C_PRIVATE_PPB_NACL_PRIVATE_H_
#define PPAPI_C_PRIVATE_PPB_NACL_PRIVATE_H_
@@ -428,16 +428,14 @@ struct PPB_NaCl_Private_1_0 {
* This method may be called on any thread.
*/
void (*PostMessageToJavaScript)(PP_Instance instance, const char* message);
/* Downloads the .nexe file at the given URL to a file, and sets |handle|
* to a handle to a file containing its contents.
* If metadata for identity-based validation caching is available
* then it sets file_token_lo and file_token_lo (otherwise left untouched).
*/
void (*DownloadNexe)(PP_Instance instance,
const char* url,
- PP_FileHandle* handle,
- uint64_t* file_token_lo,
- uint64_t* file_token_hi,
+ struct PP_NaClFileInfo* file_info,
struct PP_CompletionCallback callback);
/* Downloads a non-nexe file specified in the manifest, and sets |file_info|
* to corresponding information about the file. */
@@ -428,16 +428,14 @@ struct PPB_NaCl_Private_1_0 {
*/
void (*PostMessageToJavaScript)(PP_Instance instance, const char* message);
- /* Downloads the .nexe file at the given URL to a file, and sets |handle|
- * to a handle to a file containing its contents.
+ /* Downloads the .nexe file at the given URL to a file, and sets |file_info|
+ * to information for a handle to a file containing its contents.
* If metadata for identity-based validation caching is available
@@ -428,16 +428,14 @@ struct PPB_NaCl_Private_1_0 {
* If metadata for identity-based validation caching is available
- * then it sets file_token_lo and file_token_lo (otherwise left untouched).
+ * then it sets token information in |file_info| (otherwise left untouched).
*/
void (*DownloadNexe)(PP_Instance instance,